==> cobalt-0.0.3-sources.jar: it/auties/whatsapp/model/button/template/hydrated/HydratedFourRowTemplateBuilder.java <==
package it.auties.whatsapp.model.button.template.hydrated;

public class HydratedFourRowTemplateBuilder {
    private java.util.Optional<it.auties.whatsapp.model.message.standard.DocumentMessage> titleDocument;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplateTextTitle> titleText;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.ImageMessage> titleImage;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.VideoOrGifMessage> titleVideo;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.LocationMessage> titleLocation;
    private java.lang.String body;
    private java.util.Optional<java.lang.String> footer;
    private java.util.List<it.auties.whatsapp.model.button.template.hydrated.HydratedTemplateButton> hydratedButtons;
    private java.lang.String templateId;

    public HydratedFourRowTemplateBuilder() {
        titleDocument = java.util.Optional.empty();
        titleText = java.util.Optional.empty();
        titleImage = java.util.Optional.empty();
        titleVideo = java.util.Optional.empty();
        titleLocation = java.util.Optional.empty();
        body = null;
        footer = java.util.Optional.empty();
        hydratedButtons = new java.util.ArrayList<it.auties.whatsapp.model.button.template.hydrated.HydratedTemplateButton>();
        templateId = null;
    }

    public HydratedFourRowTemplateBuilder titleDocument(java.util.Optional<it.auties.whatsapp.model.message.standard.DocumentMessage> titleDocument) {
        this.titleDocument = titleDocument;
        return this;
    }
    public HydratedFourRowTemplateBuilder titleDocument(it.auties.whatsapp.model.message.standard.DocumentMessage titleDocument) {
        this.titleDocument = java.util.Optional.ofNullable(titleDocument);
        return this;
    }
    public HydratedFourRowTemplateBuilder titleText(java.util.Optional<it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplateTextTitle> titleText) {
        this.titleText = titleText;
        return this;
    }
    public HydratedFourRowTemplateBuilder titleText(it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplateTextTitle titleText) {
        this.titleText = java.util.Optional.ofNullable(titleText);
        return this;
    }
    public HydratedFourRowTemplateBuilder titleImage(java.util.Optional<it.auties.whatsapp.model.message.standard.ImageMessage> titleImage) {
        this.titleImage = titleImage;
        return this;
    }
    public HydratedFourRowTemplateBuilder titleImage(it.auties.whatsapp.model.message.standard.ImageMessage titleImage) {
        this.titleImage = java.util.Optional.ofNullable(titleImage);
        return this;
    }
    public HydratedFourRowTemplateBuilder titleVideo(java.util.Optional<it.auties.whatsapp.model.message.standard.VideoOrGifMessage> titleVideo) {
        this.titleVideo = titleVideo;
        return this;
    }
    public HydratedFourRowTemplateBuilder titleVideo(it.auties.whatsapp.model.message.standard.VideoOrGifMessage titleVideo) {
        this.titleVideo = java.util.Optional.ofNullable(titleVideo);
        return this;
    }
    public HydratedFourRowTemplateBuilder titleLocation(java.util.Optional<it.auties.whatsapp.model.message.standard.LocationMessage> titleLocation) {
        this.titleLocation = titleLocation;
        return this;
    }
    public HydratedFourRowTemplateBuilder titleLocation(it.auties.whatsapp.model.message.standard.LocationMessage titleLocation) {
        this.titleLocation = java.util.Optional.ofNullable(titleLocation);
        return this;
    }
    public HydratedFourRowTemplateBuilder body(java.lang.String body) {
        this.body = body;
        return this;
    }
    public HydratedFourRowTemplateBuilder footer(java.util.Optional<java.lang.String> footer) {
        this.footer = footer;
        return this;
    }
    public HydratedFourRowTemplateBuilder footer(java.lang.String footer) {
        this.footer = java.util.Optional.ofNullable(footer);
        return this;
    }
    public HydratedFourRowTemplateBuilder hydratedButtons(java.util.List<it.auties.whatsapp.model.button.template.hydrated.HydratedTemplateButton> hydratedButtons) {
        this.hydratedButtons = hydratedButtons;
        return this;
    }
    public HydratedFourRowTemplateBuilder templateId(java.lang.String templateId) {
        this.templateId = templateId;
        return this;
    }

    public it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate build() {
        return new it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate(titleDocument, titleText, titleImage, titleVideo, titleLocation, body, footer, hydratedButtons, templateId);
    }
}

==> cobalt-0.0.7-sources.jar: it/auties/whatsapp/model/button/template/hydrated/HydratedFourRowTemplateBuilder.java <==
package it.auties.whatsapp.model.button.template.hydrated;

public class HydratedFourRowTemplateBuilder {
    private java.util.Optional<it.auties.whatsapp.model.message.standard.DocumentMessage> titleDocument;
    private java.util.Optional<it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplateTextTitle> titleText;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.ImageMessage> titleImage;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.VideoOrGifMessage> titleVideo;
    private java.util.Optional<it.auties.whatsapp.model.message.standard.LocationMessage> titleLocation;
    private java.lang.String body;
    private java.util.Optional<java.lang.String> footer;
    private java.util.List<it.auties.whatsapp.model.button.template.hydrated.HydratedTemplateButton> hydratedButtons;
    private java.lang.String templateId;

    public HydratedFourRowTemplateBuilder() {
        titleDocument = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        titleText = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        titleImage = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        titleVideo = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        titleLocation = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        body = null;
        footer = it.auties.protobuf.builtin.ProtobufOptionalMixin.newOptional();
        hydratedButtons = it.auties.protobuf.builtin.ProtobufRepeatedMixin.newList();
        templateId = null;
    }

    public HydratedFourRowTemplateBuilder titleDocument(it.auties.whatsapp.model.message.standard.DocumentMessage titleDocument) {
        this.titleDocument = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(titleDocument);
        return this;
    }

    public HydratedFourRowTemplateBuilder titleText(it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplateTextTitle titleText) {
        this.titleText = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(titleText);
        return this;
    }

    public HydratedFourRowTemplateBuilder titleImage(it.auties.whatsapp.model.message.standard.ImageMessage titleImage) {
        this.titleImage = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(titleImage);
        return this;
    }

    public HydratedFourRowTemplateBuilder titleVideo(it.auties.whatsapp.model.message.standard.VideoOrGifMessage titleVideo) {
        this.titleVideo = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(titleVideo);
        return this;
    }

    public HydratedFourRowTemplateBuilder titleLocation(it.auties.whatsapp.model.message.standard.LocationMessage titleLocation) {
        this.titleLocation = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(titleLocation);
        return this;
    }

    public HydratedFourRowTemplateBuilder body(java.lang.String body) {
        this.body = body;
        return this;
    }

    public HydratedFourRowTemplateBuilder footer(java.lang.String footer) {
        this.footer = it.auties.protobuf.builtin.ProtobufOptionalMixin.ofOptional(footer);
        return this;
    }

    public HydratedFourRowTemplateBuilder hydratedButtons(java.util.List<it.auties.whatsapp.model.button.template.hydrated.HydratedTemplateButton> hydratedButtons) {
        this.hydratedButtons = hydratedButtons;
        return this;
    }

    public HydratedFourRowTemplateBuilder templateId(java.lang.String templateId) {
        this.templateId = templateId;
        return this;
    }

    public it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate build() {
        return new it.auties.whatsapp.model.button.template.hydrated.HydratedFourRowTemplate(titleDocument, titleText, titleImage, titleVideo, titleLocation, body, footer, hydratedButtons, templateId);
    }

}
